import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Box, chakra, useCheckbox, } from '@chakra-ui/react';
/**
 * Renders a button that acts like a checkbox, and looks similar to the Chakra
 * Tag component.
 *
 * Its primary use is as a control in a checkbox group.
 *
 * Can optionally display an icon, and has 2 sizes (change size by passing size='sm')
 *
 * State is handled by the Chakra hook `useCheckboxGroup` like so:
 *
 * @example
 *
 * ```tsx
 * const Tags = () => {
 *   const { value, setValue, getCheckboxProps } = useCheckboxGroup({
 *     defaultValue: ['foo'],
 *   });
 *   // note that you can imperatively `setValue(['foo'])`
 *
 *   return (
 *     <>
 *       <InteractableTag
 *         label="Foo"
 *         checkboxProps={getCheckboxProps({ value: 'foo' })}
 *       />
 *       <InteractableTag
 *         label="Bar"
 *         checkboxProps={getCheckboxProps({ value: 'bar' })}
 *       />
 *       <output>{JSON.stringify(value)}</output>
 *     </>
 *   );
 * }
 * ```
 *
 * @see https://chakra-ui.com/docs/hooks/use-checkbox-group
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/checkbox/src/use-checkbox-group.ts
 */
export function InteractableTag({ icon, label, size, checkboxProps, isDisabled, }) {
    const { state, getCheckboxProps, getInputProps, getLabelProps, htmlProps } = useCheckbox({ ...checkboxProps, isDisabled });
    return (_jsxs(chakra.label, { sx: {
            display: 'flex',
            flexDirection: 'row',
            alignItems: 'center',
            gridColumnGap: 2,
            // TODO prefer chakra theming
            h: size == 'sm' ? '26px' : '36px',
            px: 3,
            py: 1,
            bg: state.isChecked ? 'link.500' : 'white',
            color: state.isChecked ? 'white' : 'gray.500',
            borderColor: state.isChecked ? 'link.500' : 'gray.300',
            border: '1px solid',
            borderRadius: '2px',
            rounded: 'sm',
            fontSize: '14px',
            // TODO further differentiate isDisabled state
            cursor: isDisabled ? 'not-allowed' : 'pointer',
            transition: 'all 0.10s ease-in',
        }, ...htmlProps, ...getCheckboxProps(), children: [icon, _jsx("input", { ...getInputProps(), hidden: true }), _jsx(Box, { ...getLabelProps(), sx: { userSelect: 'none', textTransform: 'capitalize' }, children: label })] }));
}
//# sourceMappingURL=InteractableTag.js.map