import { type GroupBase, type Props as ReactSelectProps } from 'chakra-react-select';
type OptionType = Record<string, unknown>;
export type AutocompleteOption = {
    value: string;
    label: string;
};
/**
 * Within the context of the `onChange` callback of a CreatableAutocomplete,
 * the first argument is the AutocompleteOption with an undocumented possible
 * extra property `__isNew__`, which is present as `true` if the option was
 * entered by the user.
 *
 * ```tsx
 * <CreatableAutocomplete
 *   onChange={(
 *     value: CreateableOnChangeOption,
 *     actionMeta: ActionMeta<AutocompleteOption>,
 *   ) => {
 *     // ...
 *   }}
 * />
 * ```
 */
export type CreateableOnChangeOption = (AutocompleteOption & {
    /** Present as `true` if the current option was entered by the user */
    __isNew__?: true;
}) | null;
type AutocompleteProps<Option extends OptionType, IsMulti extends boolean = false, Group extends GroupBase<Option> = GroupBase<Option>> = ReactSelectProps<Option, IsMulti, Group>;
/**
 * Provides a react-select Autocomplete widget with Chakra fields
 *
 * - https://github.com/csandman/chakra-react-select
 * - https://react-select.com
 *
 * ## Styling
 *
 * > There are a few ways to style the components that make up
 * > chakra-react-select. It's important to note that this package does not use
 * > the theme or styles props that are implemented in react-select. The theme
 * > prop isn't used as most of the components' base styles are pulling from
 * > your Chakra theme, and customizing your base theme (such as colors or
 * > component styles) should in turn change the styles in this package.
 * >
 * > This package does however offer an alternative to the styles prop,
 * > [chakraStyles](https://github.com/csandman/chakra-react-select#chakrastyles).
 * > It mostly emulates the behavior of the original styles prop, however,
 * > because it’s not identical it is named differently to prevent confusion.
 *
 * https://github.com/csandman/chakra-react-select#styling
 *
 * @example
 *
 * ```tsx
 * <Autocomplete
 *   options={[
 *     { id: 0, label: 'alpha' },
 *     { id: 1, label: 'beta' },
 *   ]}
 *   placeholder="Select something"
 * />
 * ```
 */
export declare function Autocomplete<Option extends OptionType, IsMulti extends boolean = false, Group extends GroupBase<Option> = GroupBase<Option>>({ chakraStyles, ...props }: AutocompleteProps<Option, IsMulti, Group>): import("react/jsx-runtime").JSX.Element;
/**
 * Returns a react-select instance that enables users to create new options
 * along with choosing existing options.
 *
 * - https://react-select.com/creatable
 * - https://react-select.com/props#creatable-props
 */
export declare function CreatableAutocomplete<Option extends OptionType, IsMulti extends boolean = false, Group extends GroupBase<Option> = GroupBase<Option>>({ chakraStyles, ...props }: AutocompleteProps<Option, IsMulti, Group>): import("react/jsx-runtime").JSX.Element;
/**
 * Returns a react-select instance that can load options from a remote source as
 * the user types.
 *
 * - https://react-select.com/async
 */
export declare function AsyncAutocomplete<Option extends OptionType, IsMulti extends boolean = false, Group extends GroupBase<Option> = GroupBase<Option>>({ chakraStyles, ...props }: AutocompleteProps<Option, IsMulti, Group>): import("react/jsx-runtime").JSX.Element;
/**
 * Returns a react-select instance that enables users to create new options
 * along with options loaded a remote source.
 *
 * - https://react-select.com/creatable
 * - https://react-select.com/async
 */
export declare function AsyncCreatableAutocomplete<Option extends OptionType, IsMulti extends boolean = false, Group extends GroupBase<Option> = GroupBase<Option>>({ chakraStyles, ...props }: AutocompleteProps<Option, IsMulti, Group>): import("react/jsx-runtime").JSX.Element;
export {};
