import { jsx as _jsx } from "react/jsx-runtime";
import { AsyncCreatableSelect as ChakraReactAsyncCreatableSelect, AsyncSelect as ChakraReactAsyncSelect, CreatableSelect as ChakraReactCreatableSelect, Select as ChakraReactSelect, } from 'chakra-react-select';
import { autocompleteChakraStyles } from './Autocomplete.styles';
/**
 * Provides a react-select Autocomplete widget with Chakra fields
 *
 * - https://github.com/csandman/chakra-react-select
 * - https://react-select.com
 *
 * ## Styling
 *
 * > There are a few ways to style the components that make up
 * > chakra-react-select. It's important to note that this package does not use
 * > the theme or styles props that are implemented in react-select. The theme
 * > prop isn't used as most of the components' base styles are pulling from
 * > your Chakra theme, and customizing your base theme (such as colors or
 * > component styles) should in turn change the styles in this package.
 * >
 * > This package does however offer an alternative to the styles prop,
 * > [chakraStyles](https://github.com/csandman/chakra-react-select#chakrastyles).
 * > It mostly emulates the behavior of the original styles prop, however,
 * > because it’s not identical it is named differently to prevent confusion.
 *
 * https://github.com/csandman/chakra-react-select#styling
 *
 * @example
 *
 * ```tsx
 * <Autocomplete
 *   options={[
 *     { id: 0, label: 'alpha' },
 *     { id: 1, label: 'beta' },
 *   ]}
 *   placeholder="Select something"
 * />
 * ```
 */
export function Autocomplete({ chakraStyles, ...props }) {
    return (_jsx(ChakraReactSelect, { useBasicStyles: true, chakraStyles: { ...autocompleteChakraStyles, ...chakraStyles }, ...props }));
}
/**
 * Returns a react-select instance that enables users to create new options
 * along with choosing existing options.
 *
 * - https://react-select.com/creatable
 * - https://react-select.com/props#creatable-props
 */
export function CreatableAutocomplete({ chakraStyles, ...props }) {
    return (_jsx(ChakraReactCreatableSelect, { useBasicStyles: true, chakraStyles: { ...autocompleteChakraStyles, ...chakraStyles }, ...props }));
}
/**
 * Returns a react-select instance that can load options from a remote source as
 * the user types.
 *
 * - https://react-select.com/async
 */
export function AsyncAutocomplete({ chakraStyles, ...props }) {
    return (_jsx(ChakraReactAsyncSelect, { useBasicStyles: true, chakraStyles: { ...autocompleteChakraStyles, ...chakraStyles }, ...props }));
}
/**
 * Returns a react-select instance that enables users to create new options
 * along with options loaded a remote source.
 *
 * - https://react-select.com/creatable
 * - https://react-select.com/async
 */
export function AsyncCreatableAutocomplete({ chakraStyles, ...props }) {
    return (_jsx(ChakraReactAsyncCreatableSelect, { useBasicStyles: true, chakraStyles: { ...autocompleteChakraStyles, ...chakraStyles }, ...props }));
}
//# sourceMappingURL=Autocomplete.js.map