import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Code, FormControl, FormHelperText, FormLabel, VStack, } from '@chakra-ui/react';
import { useState } from 'react';
import { getThemingArgTypes, } from '@burnsred/utils-storybook';
import { colorOptions, colorSchemeOptions, groupedCountries, groupedOptions, } from './Autocomplete.fixtures';
import { brTheme } from '../../../theme';
import { PreJson } from '../../atoms';
import { Autocomplete } from '.';
/**
 * https://chakra-ui.com/docs/components/autocomplete
 *
 * The upstream library has many examples, (only some of which have been replicated below):
 *
 * - https://codesandbox.io/s/chakra-react-select-sizes-w9sf8e?file=/example.js:1236-1440
 * - https://codesandbox.io/s/chakra-react-select-color-schemes-c38jlo?file=/example.js:1424-1547
 * - https://codesandbox.io/s/chakra-react-select-tag-variants-w31gnt?file=/example.js:1378-1392
 * - https://codesandbox.io/s/chakra-react-select-invalid-disabled-0hyl8l?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-border-colors-gjo4zd?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-usebasicstyles-jjnqsd?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-border-selectedoptionstyle-yxkcos?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-border-selectedoptioncolor-yyd321?file=/example.js:963-1040
 * - https://codesandbox.io/s/chakra-react-select-variant-5cf755?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-hasstickygroupheaders-wg39g?file=/docs/data.js
 * - https://codesandbox.io/s/chakra-react-select-border-selectedoptionstyle-yxkcos?file=/example.js
 */
const meta = {
    title: 'Components/Widgets/Autocomplete',
    component: Autocomplete,
    args: {
        options: colorOptions,
        placeholder: 'Select some colors...',
        size: 'sm',
    },
    argTypes: {
        // namespace: { control: 'text' },
        size: { control: 'text' },
        ...getThemingArgTypes(brTheme, 'Select'),
    },
    decorators: [
        (Story) => (_jsx("div", { style: { height: '240px' }, children: _jsx(Story, {}) })),
    ],
};
export default meta;
/** https://codesandbox.io/s/chakra-react-select-border-selectedoptionstyle-yxkcos?file=/example.js:723-736 */
export const Primary = {
    args: {
        options: colorOptions,
        placeholder: 'Select some colors...',
        size: 'sm',
    },
};
/**
 * Demonstrates use of the `onChange` callback to set state,
 * and transforming options to the required format.
 */
export const WithParentState = {
    render: () => {
        // eslint-disable-next-line react-hooks/rules-of-hooks
        const [state, setState] = useState({
            selectedOption: '',
        });
        const rawOptions = ['Alpha', 'Beta'];
        /**
         * Example of transforming options to the proper format, resulting in:
         *
         * ```tsx
         * <Autocomplete
         *   options={[
         *     { value: 'foo', label: 'Foo' },
         *     { value: 'bar', label: 'Far' },
         *   ]}
         * />
         * ```
         */
        const transformedOptions = rawOptions.map((option) => ({ value: option.toLowerCase(), label: option }));
        const handleChange = (selectedOption, 
        /**
         * type ActionTypes = | 'clear' | 'create-option' | 'deselect-option' | 'pop-value' | 'remove-value' | 'select-option' | 'set-value'
         *
         * https://react-select.com/props
         */
        actionMeta) => {
            console.log('[onChange]', { newValue: selectedOption, actionMeta });
            if (actionMeta.action === 'clear')
                return setState({ selectedOption: '' });
            if (!selectedOption)
                return;
            setState({ selectedOption: selectedOption.value });
        };
        return (_jsxs(VStack, { align: "left", gap: "6", children: [_jsx(Autocomplete, { options: transformedOptions, onChange: handleChange, isClearable: true }), _jsx(PreJson, { heading: "Parent State", data: state })] }));
    },
};
/**
 * These extend our defaults in Autocomplete.styles.tsx
 *
 * See https://github.com/csandman/chakra-react-select#chakrastyles
 * for a complete list of styleable elements.
 *
 * ```ts
 * <Autocomplete
 *   chakraStyles: {
 *     control: (prev) => ({
 *       ...prev,
 *       bg: 'purple.200',
 *     }),
 *
 *     // uses theme styles for Chakra's CloseButton
 *     clearIndicator: (prev) => ({
 *       ...prev,
 *       color: 'error',
 *       _hover: {
 *         bg: 'error',
 *
 *         '> svg': {
 *           color: 'white',
 *         },
 *       },
 *     }),
 *   }
 * />
 * ```
 */
export const CustomStyles = {
    args: {
        chakraStyles: {
            control: (prev) => ({
                ...prev,
                bg: 'purple.200',
            }),
            // uses theme styles for Chakra's CloseButton
            clearIndicator: (prev) => ({
                ...prev,
                color: 'error',
                _hover: {
                    bg: 'error',
                    '> svg': {
                        color: 'white',
                    },
                },
            }),
        },
        isClearable: true,
        placeholder: null,
        options: [
            { value: 'foo', label: 'foo' },
            { value: 'bar', label: 'bar' },
        ],
        defaultValue: { value: 'foo', label: 'foo' },
    },
};
/** Display a Check icon to the left of the selected option */
export const SelectOptionCheck = {
    args: {
        selectedOptionStyle: 'check',
    },
};
/**
 * Medium Select `size="md"`
 */
// https://codesandbox.io/s/chakra-react-select-sizes-w9sf8e?file=/example.js
export const Sizes = {
    args: {
        isMulti: true,
        // classNamePrefix: 'chakra-react-select',
        options: groupedOptions,
        placeholder: 'Select some colors...',
        closeMenuOnSelect: false,
        size: 'md',
    },
};
/**
 * Sets a colorScheme for each selected option
 */
// https://codesandbox.io/s/chakra-react-select-sizes-w9sf8e?file=/example.js
export const ColouredOptions = {
    args: {
        isMulti: true,
        name: 'option-color-scheme',
        options: colorSchemeOptions,
        placeholder: 'Select some colors...',
    },
};
/**
 * Use a variant to display selected Tags
 *
 * It's also possible to set each tag to display using a separate variant:
 * [CodeSandBox](https://codesandbox.io/s/chakra-react-select-tag-variants-w31gnt?file=/example.js)
 */
export const OptionsTagVariants = {
    args: {
        isMulti: true,
        name: 'global-tag-variant',
        tagVariant: 'outline',
        options: colorOptions,
        placeholder: 'Select some colors...',
    },
};
/**
 * When disabled at the FormControl level, the FormLabel is blurred along with the select
 */
// https://codesandbox.io/s/chakra-react-select-invalid-disabled-0hyl8l?file=/example.js
export const DisabledFromFormGroup = {
    args: {
        ...Primary.args,
        options: colorOptions,
    },
    render: (args) => (_jsxs(FormControl, { isDisabled: true, children: [_jsxs(FormLabel, { children: ["Disabled from the ", _jsx(Code, { children: "FormControl" })] }), _jsx(Autocomplete, { ...args }), _jsx(FormHelperText, { children: "When disabled at the FormControl level, the FormLabel is blurred along with the select" })] })),
};
/**
 * With selectedOptionColor="teal"
 */
export const SelectedColorOption = {
    args: {
        ...Primary.args,
        selectedOptionColor: 'teal',
        closeMenuOnSelect: false,
    },
};
/**
 * _(countries options have been truncated)_
 */
export const StickyOptionHeaders = {
    args: {
        name: 'grouped-countries',
        isMulti: true,
        options: groupedCountries,
        placeholder: 'Select some countries...',
        closeMenuOnSelect: false,
        hasStickyGroupHeaders: true,
    },
};
/**
 *
 */
export const _Variants = {
    args: {},
};
//# sourceMappingURL=Autocomplete.stories.js.map