import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { chakra } from '@chakra-ui/react';
import { useRef, useState } from 'react';
import { useDropzone } from 'react-dropzone';
import { MdClose } from 'react-icons/md';
import { FileContent, FileDeleteAction, FileListContainer, FileName, FilePickerContainer, FileRejectReason, FileRowContainer, } from './FilePicker.styles';
const MAX_FILE_SIZE = 20971520;
const defaultFileTypeRestrictions = {
    'image/png': ['.png'],
    'image/gif': ['.gif'],
    'image/jpeg': ['.jpg', '.jpeg'],
    'application/msword': ['.doc'],
    'application/vnd.openxmlformats-officedocument.wordprocessingml.document': [
        '.docx',
    ],
    'application/vnd.ms-excel': ['.xls'],
    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet': [
        '.xlsx',
    ],
    'application/vnd.ms-powerpoint': ['.ppt'],
    'application/vnd.openxmlformats-officedocument.presentationml.presentation': [
        '.pptx',
    ],
    'application/pdf': ['.pdf'],
    'text/plain': ['.txt'],
    'audio/mp3': ['.mp3'],
    'audio/mp4': ['.mp4'],
    'audio/wav': ['.wav'],
    'video/mpeg': ['.mpeg', '.mpg'],
    'video/mov': ['.mov'],
    'video/wmv': ['.wmv'],
};
const defaultFilePickerMessage = (_jsxs(_Fragment, { children: ["Drag and drop files here or ", _jsx("span", { children: "click to select files." })] }));
/**
 * FilePicker renders a 'drag and drop' zone file selector. The component acts as a zone
 * while also allowing users to select the message to open the OS File Browser.
 *
 * The drop zone renders a single standard html file input field, which has a property `files`
 * When files are dropped on the drop zone, then synchronous local validation occurs, and
 * each file is displayed under the widget with it's validation status. If the file is accepted,
 * it is appended to the file input. Rejected files are not appended to the file input.
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input/file
 */
export const FilePicker = ({ isDisabled = false, fileLimit = 1, message = defaultFilePickerMessage, fileTypeRestrictions = defaultFileTypeRestrictions, showFileList = true, fileSizeRestriction = MAX_FILE_SIZE, }) => {
    const [localFileList, setLocalFileList] = useState([]);
    const inputRef = useRef(null);
    const onDrop = (acceptedFiles, fileRejections) => {
        fileRejections.forEach((file) => {
            file.errors.forEach((err) => {
                if (err.code === 'file-too-large') {
                    setLocalFileList(() => [
                        ...localFileList,
                        {
                            accepted: false,
                            file: file.file,
                            message: err.message,
                        },
                    ]);
                    return;
                }
                if (err.code === 'file-invalid-type') {
                    setLocalFileList(() => [
                        ...localFileList,
                        {
                            accepted: false,
                            file: file.file,
                            message: 'The file type you selected is not allowed.',
                        },
                    ]);
                    return;
                }
                if (err.code === 'file-already-exists') {
                    setLocalFileList(() => [
                        ...localFileList,
                        {
                            accepted: false,
                            file: file.file,
                            message: err.message,
                        },
                    ]);
                    return;
                }
            });
        });
        if (inputRef.current?.files && acceptedFiles.length > 0) {
            const dataTransfer = new DataTransfer();
            acceptedFiles.forEach((file) => {
                setLocalFileList(() => [
                    ...localFileList,
                    {
                        accepted: true,
                        file: file,
                        message: null,
                    },
                ]);
                dataTransfer.items.add(file);
            });
            inputRef.current.files = dataTransfer.files;
        }
    };
    const customFileValidator = (file) => {
        if (file.size > fileSizeRestriction) {
            return {
                code: 'file-too-large',
                message: 'The file you selected is too large.',
            };
        }
        if (localFileList.some((localFile) => localFile.file.name === file.name))
            return {
                code: 'file-already-exists',
                message: 'The file you selected already exists.',
            };
        return null;
    };
    const { getRootProps, getInputProps } = useDropzone({
        disabled: isDisabled,
        maxFiles: fileLimit,
        accept: fileTypeRestrictions,
        validator: customFileValidator,
        onDrop,
    });
    const handleLocalFileDelete = (index) => {
        const newArray = localFileList.slice();
        const focusFile = localFileList[index];
        if (focusFile.accepted) {
            handleInputFileDelete(focusFile.file);
        }
        newArray.splice(index, 1);
        setLocalFileList(newArray);
    };
    const handleInputFileDelete = (file) => {
        if (inputRef.current && inputRef.current.files) {
            const currentFileList = inputRef.current.files;
            const filteredFileList = [...currentFileList].filter((f) => file.name !== f.name);
            const dataTransfer = new DataTransfer();
            filteredFileList.forEach((file) => {
                dataTransfer.items.add(file);
            });
            inputRef.current.files = dataTransfer.files;
        }
        else {
            return;
        }
    };
    // If EntityLibrary work requires the onChange for the hidden file input, we
    // will need to manually trigger the onChange as setting the file of files in Ref
    // doesn't trigger it.
    console.log('[inputRef.current.files], ', inputRef.current?.files);
    return (_jsx(_Fragment, { children: _jsxs(FilePickerContainer, { children: [_jsxs(chakra.div, { "data-testid": "dropzone-container", ...getRootProps({ className: 'dropzone' }), "data-disabled": isDisabled, children: [_jsx("input", { "data-testid": "dropzone-input", ...getInputProps(), disabled: isDisabled }), _jsx("input", { type: "file", style: { display: 'none' }, ref: inputRef }), message] }), showFileList && localFileList.length > 0 && (_jsx(FileListContainer, { children: localFileList.map((file, index) => (_jsx(FileRow, { onDelete: () => handleLocalFileDelete(index), children: file }, index))) }))] }) }));
};
const FileRow = ({ children, onDelete, }) => {
    return (_jsxs(FileRowContainer, { status: children.accepted, children: [_jsx(FileContent, { children: _jsxs(_Fragment, { children: [_jsx(FileName, { children: children.file.name }), !children.accepted && (_jsx(FileRejectReason, { children: children.message }))] }) }), _jsx(FileDeleteAction, { children: _jsx(MdClose, { onClick: onDelete }) })] }));
};
//# sourceMappingURL=FilePicker.js.map