import { type FormControlProps, type FormLabelProps, type InputProps } from '@chakra-ui/react';
import { type ChangeEventHandler } from 'react';
type InputFieldProps = {
    colSpan?: number;
    errorMessage?: string;
    helpText?: string;
    onChange?: ChangeEventHandler<HTMLInputElement | HTMLTextAreaElement>;
} & Pick<InputProps, 'name' | 'type' | 'value' | 'autoFocus' | 'autoComplete' | 'placeholder' | 'size' | 'colorScheme' | 'variant'> & Pick<FormControlProps, 'label' | 'isRequired' | 'isDisabled' | 'isInvalid' | 'isReadOnly'> & Pick<FormLabelProps, 'requiredIndicator' | 'optionalIndicator'>;
/**
 * Input field for forms which composes FormControl, FormLabel, Input,
 * FormHelperText, FormErrorText in a GridItem.
 *
 * This component is intended to render text-ish inputs or textarea - other
 * types such as button are better served by using a more specific component.
 *
 * ```tsx
 *
 * // before:
 * <GridItem>
 *   <FormControl>
 *     <FormLabel>{label}</FormLabel>
 *     <Input />
 *     {!isInvalid ? (
 *       <FormHelperText>{helpText}</FormHelperText>
 *     ) : (
 *       <FormErrorMessage>{errorMessage}</FormErrorMessage>
 *     )}
 *   </FormControl>
 * </GridItem>
 *
 * // after:
 * <InputField
 *   name="long"
 *   helpText=""
 *   colsSpan={10}
 *   {...props}
 * />
 * ```
 *
 * InputFields can be nested inside FieldGroup for simple field layout:
 *
 * ```tsx
 * <FieldGroup templateColumns={12}>
 *   <InputField name="short" colSpan={2} />
 *   <InputField
 *     name="long"
 *     helpText=""
 *     colsSpan={10}
 *     {...props}
 *   />
 * </FieldGroup>
 *  ```
 *
 * Provide a type to change the kind of input the InputField will be, eg: number, email, password etc..
 *
 * ```tsx
 *   <InputField
 *     name="Number Input"
 *     type="number"
 *     helpText=""
 *     colsSpan={10}
 *     {...props}
 *   />
 *  ```
 *
 */
export declare const InputField: ({ colSpan, onChange, errorMessage, helpText, isRequired, isDisabled, isInvalid, isReadOnly, requiredIndicator, optionalIndicator, type, name, value, label, placeholder, ...inputProps }: InputFieldProps) => import("react/jsx-runtime").JSX.Element;
export {};
