import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { FormControl, FormErrorMessage, FormHelperText, FormLabel, GridItem, Input, Textarea, } from '@chakra-ui/react';
// FormErrorMessageProps &
// FormHelperTextProps;
/**
 * Input field for forms which composes FormControl, FormLabel, Input,
 * FormHelperText, FormErrorText in a GridItem.
 *
 * This component is intended to render text-ish inputs or textarea - other
 * types such as button are better served by using a more specific component.
 *
 * ```tsx
 *
 * // before:
 * <GridItem>
 *   <FormControl>
 *     <FormLabel>{label}</FormLabel>
 *     <Input />
 *     {!isInvalid ? (
 *       <FormHelperText>{helpText}</FormHelperText>
 *     ) : (
 *       <FormErrorMessage>{errorMessage}</FormErrorMessage>
 *     )}
 *   </FormControl>
 * </GridItem>
 *
 * // after:
 * <InputField
 *   name="long"
 *   helpText=""
 *   colsSpan={10}
 *   {...props}
 * />
 * ```
 *
 * InputFields can be nested inside FieldGroup for simple field layout:
 *
 * ```tsx
 * <FieldGroup templateColumns={12}>
 *   <InputField name="short" colSpan={2} />
 *   <InputField
 *     name="long"
 *     helpText=""
 *     colsSpan={10}
 *     {...props}
 *   />
 * </FieldGroup>
 *  ```
 *
 * Provide a type to change the kind of input the InputField will be, eg: number, email, password etc..
 *
 * ```tsx
 *   <InputField
 *     name="Number Input"
 *     type="number"
 *     helpText=""
 *     colsSpan={10}
 *     {...props}
 *   />
 *  ```
 *
 */
export const InputField = ({ 
/** for use when InputField is nested inside a FieldGroup */
colSpan = 1, onChange, errorMessage, // TODO will be provided by Duck
helpText, // TODO will be provided by Duck
// FormControlProps
isRequired, isDisabled, isInvalid, isReadOnly, 
// FormLabelProps
requiredIndicator, optionalIndicator, 
// FormErrorMessageProps
// just styles
// FormHelperTextProps
// just styles
// InputProps
type = 'text', name, value, 
// FIXME conflict with onInputChange
// onChange,
label, placeholder, ...inputProps }) => {
    return (_jsx(GridItem, { colSpan: colSpan, children: _jsxs(FormControl, { isReadOnly: isReadOnly, isDisabled: isDisabled, isInvalid: isInvalid, isRequired: isRequired, children: [_jsx(FormLabel, { requiredIndicator: requiredIndicator, optionalIndicator: optionalIndicator, children: label }), 
                // https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#input_types
                type !== 'textarea' ? (_jsx(Input, { type: type, name: name, value: value, onChange: onChange, placeholder: placeholder, ...inputProps })) : (_jsx(Textarea, { name: name, value: value, onChange: onChange, placeholder: placeholder, ...inputProps })), !isInvalid ? (_jsx(FormHelperText, { children: helpText })) : (_jsx(FormErrorMessage, { children: errorMessage }))] }) }));
};
//# sourceMappingURL=InputField.js.map