import { jsx as _jsx } from "react/jsx-runtime";
import { ChakraProvider } from '@chakra-ui/react';
import { cleanup, render } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import { BrowserRouter } from 'react-router-dom';
import { brTheme } from '..';
afterEach(() => {
    cleanup();
});
/**
 * @see https://github.com/vitest-dev/vitest/blob/main/examples/react-testing-lib/src/utils/test-utils.tsx
 */
export const renderWithTheme = (ui, { theme, ...renderOptions } = {}) => ({
    user: userEvent.setup(),
    ...render(ui, {
        wrapper: ({ children }) => (_jsx(ChakraProvider, { theme: theme ?? brTheme, children: children })),
        ...renderOptions,
    }),
});
/**
 * TLDR; see test/example./react-router.test.tsx
 *
 * @example
 *
 * ```tsx
 * test('rendering a component that requires Router context', async () => {
 *   renderWithRouter(<ComponentWithUseReactRouterHook />);
 *   expect(...).toBeInTheDocument();
 * });
 * ```
 *
 * @example
 *
 * ```tsx
 * test('rendering a component that uses useLocation', () => {
 *   const route = '/some-route'
 *   renderWithRouter(<LocationDisplay />, {route})
 *
 *   expect(screen.getByTestId('location-display')).toHaveTextContent(route)
 * })
 * ```
 *
 * @example
 *
 * Note that it can be inefficient and tricky to use our production app routes:
 *
 * ```tsx
 * test('using our full routes', async () => {
 *   const TestApp = () => (
 *     <AuthProvider>
 *       <Routes>{appRoutes}</Routes>
 *       <LocationDisplay />
 *     </AuthProvider>
 *   );
 *
 *   renderWithRouter(<TestApp />, {
 *     route: '/login',
 *   });
 *
 *   const heading = await screen.findByRole('heading');
 *   expect(heading).toHaveTextContent('Sign in');
 * });
 * ```
 *
 * @see https://testing-library.com/docs/example-react-router/#reducing-boilerplate
 */
export const renderWithRouter = (ui, options = {}) => {
    const { route, ...renderOptions } = options;
    window.history.pushState({}, 'Test page', route ?? '/');
    return {
        user: userEvent.setup(),
        ...render(ui, {
            wrapper: BrowserRouter,
            ...renderOptions,
        }),
    };
};
/**
 * RTL render function which returns `user` ready for use
 *
 * @example
 *
 * ```tsx
 * test('render returns user', () => {
 *   const { user} = render(<button>My Button</button>)
 *   const button = screen.getByRole('button', { name: /my button/i })
 *   user.click(button)
 *   // ...
 * })
 * ```
 */
export const renderWithUserEvent = (ui, renderOptions = {}) => ({
    user: userEvent.setup(),
    ...render(ui, renderOptions),
});
// override the default `render` to include `user`
// eslint-disable-next-line import/export
export * from '@testing-library/react';
// eslint-disable-next-line import/export
export { renderWithUserEvent as render };
// also make userEvent available from here
export { default as userEvent } from '@testing-library/user-event';
//# sourceMappingURL=utils.js.map