import { useMatches } from 'react-router-dom';
/**
 * Allows us to type the shape of a route's custom handle properties.
 *
 * ```ts
 * type TitleRoute = RouteWithHandle<{ title: string }>
 *
 * const matches = useMatches();
 * matches.map((match) => void console.log((match as TitleRoute).handle?.title))
 * ```
 */
export type RouteWithHandle<T extends Record<string, unknown>> = Omit<ReturnType<typeof useMatches>[number], 'handle'> & {
    handle: T;
};
export type TitleRoute = RouteWithHandle<{
    title?: string;
}>;
/**
 * Returns the title for the current route defined as `route.handle.title`,
 * falling back to the deepest matching route (nearest defined ancestor),
 * or `undefined`.
 *
 * ```
 * const routes = [
 *   {
 *     path: '/',
 *     element: <div />,
 *     handle: { title: 'Parent' },
 *     children: [
 *       {
 *         // 🔵 defined `handle.title`; returns 'Child'
 *         path: 'child',
 *         handle: { title: 'Child' },
 *       },
 *       {
 *         // 🔵 no `handle.title`; returns 'Parent'
 *         path: 'nameless-child',
 *       },
 *     ]
 *   }
 * ]
 * ```
 *
 * @see https://reactrouter.com/en/main/hooks/use-matches#breadcrumbs
 */
export declare const useTitle: () => string | undefined;
