import { useMemo } from 'react';
import { useMatches } from 'react-router-dom';
/**
 * Returns the title for the current route defined as `route.handle.title`,
 * falling back to the deepest matching route (nearest defined ancestor),
 * or `undefined`.
 *
 * ```
 * const routes = [
 *   {
 *     path: '/',
 *     element: <div />,
 *     handle: { title: 'Parent' },
 *     children: [
 *       {
 *         // 🔵 defined `handle.title`; returns 'Child'
 *         path: 'child',
 *         handle: { title: 'Child' },
 *       },
 *       {
 *         // 🔵 no `handle.title`; returns 'Parent'
 *         path: 'nameless-child',
 *       },
 *     ]
 *   }
 * ]
 * ```
 *
 * @see https://reactrouter.com/en/main/hooks/use-matches#breadcrumbs
 */
export const useTitle = () => {
    const matches = useMatches();
    const title = useMemo(() => matches
        // get all routes with a defined handle.title
        // nB: `matches` includes separate entries for trailing slashes, eg:
        // [{ path: 'foo' }, { path: 'foo/' }]
        .filter((match) => Boolean(match.handle?.title))
        .map((match) => match.handle.title)
        // get the deepest match / nearest ancestor route
        .pop(), [matches]);
    return title;
};
//# sourceMappingURL=useTitle.js.map