/** Add to these as required (after careful consideration) */
export type EventCategory = 'form-submit' | 'click';
/**
 * Custom events requiring 1-4 args
 *
 * > When creating Custom Events in your analytics it is important to consider the
 * > names you use carefully, as they will remain there forever. You should use
 * > descriptive names so it is easy to understand your reports, even when you can
 * > only see the Event Category or Event Action, for example.
 * >
 * > Letter case is important when defining Event Tracking values. Video, video,
 * > VIDEO, and ViDeO would all count as different events. Using consistent and
 * > descriptive names ensures that you will be able to understand and analyse the
 * > measured event data.
 *
 * - `Category` (Required) – This describes the type of events you want to track.
 *   For example, Link Clicks, Videos, Outbound Links, and Form Events.
 * - `Action` (Required) – This is the specific action that is taken. For example,
 *   with the Video category, you might have a Play, Pause and Complete action.
 * - `Name` (Optional – Recommended) – This is usually the title of the element
 *   that is being interacted with, to aid with analysis. For example, it could
 *   be the name of a Video that was played or the specific form that is being
 *   submitted.
 * - `Value` (Optional) – This is a numeric value and is often added dynamically.
 *   It could be the cost of a product that is added to a cart, or the
 *   completion percentage of a video.
 *
 * @example
 *
 * ```js
 * trackEvent(['Downloads', 'PDF Brochure Download', 'Matomo Event Tracking Brochure', 'blank'])
 * trackEvent(['Reviews', 'Published Matomo Review', 'blank', '10'])
 * ```
 *
 * https://developer.matomo.org/guides/tracking-javascript-guide#manually-trigger-events
 * https://matomo.org/guide/reports/event-tracking/#tracking-events
 * https://matomo.org/faq/reports/the-anatomy-of-an-event/
 */
export type MatomoCustomEvent = [command: 'trackEvent', category: EventCategory] | [command: 'trackEvent', category: EventCategory, name: string] | [
    command: 'trackEvent',
    category: EventCategory,
    action: string,
    name: string
] | [
    command: 'trackEvent',
    category: EventCategory,
    action: string,
    name: string,
    value: number
];
/**
 * Matomo tracking command queue.
 *
 * '_paq' is the conventional name: 'Piwik Analytics Queue'
 * (refers to Matomo's legacy brand name)
 *
 * @see https://developer.matomo.org/guides/tracking-javascript-guide
 */
export type MatomoEvents = ['trackPageView'] | ['setDocumentTitle', string] | ['setCustomUrl', string] | ['trackAllContentImpressions'] | ['trackVisibleContentImpressions', boolean, number] | ['setUserId', string] | ['resetUserId'] | ['appendToTrackingUrl', 'new_visit=1' | ''] | MatomoCustomEvent;
/**
 * Universal function for tracking events. All other tracking utils should use this function.
 *
 * Note that the matomo script must be installed in index.html for this to work!
 */
export declare const trackEvent: (event: MatomoEvents) => void;
export declare const trackLogin: (userUuid: string) => void;
/**
 * https://developer.matomo.org/guides/tracking-javascript-guide#when-user-logs-out-reset-user-id
 */
export declare const trackLogOut: () => void;
/** Helper for form submission events which composes `trackEvent` */
export declare const trackFormSubmission: (formName: string) => void;
/**
 * Update the `document.title` and track changes _each time it changes_.
 *
 * Note that if the `document.title` doesn't update, the route change will not
 * be tracked! This will occur if a child route has no title defined, (in which
 * case it displays the title of it's nearest defined ancestor), in which case
 * navigating from /parent to /parent/nameless-child will not be tracked.
 *
 * @see useTitle for details of defining titles via `route.handle.title`
 */
export declare const useTrackPageView: (applicationName: string) => void;
export type TrackNavigationProps = {
    /** used to compose `document.title` */
    applicationName: string;
};
/**
 * Note that the matomo script must be installed in index.html for tracking to
 * function!
 */
export declare const TrackNavigation: ({ applicationName }: TrackNavigationProps) => import("react/jsx-runtime").JSX.Element;
