import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect } from 'react';
import { Outlet } from 'react-router-dom';
import { useTitle } from './useTitle';
/**
 * Universal function for tracking events. All other tracking utils should use this function.
 *
 * Note that the matomo script must be installed in index.html for this to work!
 */
export const trackEvent = (event) => {
    // console.log('⚪️ [useTrackPageView]', event);
    const _paq = (window._paq = window?._paq ?? []);
    _paq.push(event);
};
export const trackLogin = (userUuid) => {
    trackEvent(['setUserId', userUuid]);
};
/**
 * https://developer.matomo.org/guides/tracking-javascript-guide#when-user-logs-out-reset-user-id
 */
export const trackLogOut = () => {
    // User has just logged out, we reset the User ID
    trackEvent(['resetUserId']);
    // we also force a new visit to be created for the pageviews after logout
    trackEvent(['appendToTrackingUrl', 'new_visit=1']);
    trackEvent(['trackPageView']);
    // we finally make sure to not again create a new visit afterwards (important for Single Page Applications)
    trackEvent(['appendToTrackingUrl', '']);
};
/** Helper for form submission events which composes `trackEvent` */
export const trackFormSubmission = (formName) => {
    console.assert(formName, 'formName is required to track form submission');
    trackEvent(['trackEvent', 'form-submit', formName]);
};
/**
 * Update the `document.title` and track changes _each time it changes_.
 *
 * Note that if the `document.title` doesn't update, the route change will not
 * be tracked! This will occur if a child route has no title defined, (in which
 * case it displays the title of it's nearest defined ancestor), in which case
 * navigating from /parent to /parent/nameless-child will not be tracked.
 *
 * @see useTitle for details of defining titles via `route.handle.title`
 */
export const useTrackPageView = (applicationName) => {
    const title = useTitle();
    useEffect(() => {
        document.title = title ? `${title} | ${applicationName}` : applicationName;
        trackEvent(['setDocumentTitle', document.title]);
        // > By default, Matomo uses the URL of the current page as the Page URL in
        // > reports. You can customise the page URL to track by using the function
        // > `setCustomUrl`
        // https://developer.matomo.org/guides/tracking-javascript-guide#custom-page-url
        // https://matomo.org/faq/how-to/how-do-i-set-a-custom-url-using-the-matomo-javascript-tracker/
        // use window.location.href to account for the possible use of HashRouter
        trackEvent(['setCustomUrl', location.href]);
        // console.log('[trackPageView]', location.title, document.href);
        trackEvent(['trackPageView']);
    }, [applicationName, title]);
};
/**
 * Note that the matomo script must be installed in index.html for tracking to
 * function!
 */
export const TrackNavigation = ({ applicationName }) => {
    useTrackPageView(applicationName);
    return _jsx(Outlet, {});
};
//# sourceMappingURL=useTracking.js.map